@@ -15,14 +15,9 @@ using System.Text;
 using System.Collections;
 using FlickrNet;
 using FSpot;
+using FSpot.Filters;
 
 public class FlickrRemote {
-    
-	// This should be private but you know, this is Free Software ;-)
-	// Keys from acs
-	private static string     _apikey = "c6b39ee183385d9ce4ea188f85945016";
-	private static string     _sharedsecret = "0a951ac44a423a04";
-	
 	public static Licenses    licenses;
 	private string            frob;
 	private string            token;
@@ -32,22 +27,24 @@ public class FlickrRemote {
 	public bool               ExportTags;
 	public FSpot.ProgressItem Progress;
 	
-	public FlickrRemote (string token)
+	public FlickrRemote (string token, Service service)
 	{
 		if (token == null || token.Length == 0) {
-			this.flickr = new Flickr (_apikey, _sharedsecret);
+			this.flickr = new Flickr (service.ApiKey, service.Secret);
 			this.token = null;
 		} else {
-			this.flickr = new Flickr (_apikey, _sharedsecret, token);
+			this.flickr = new Flickr (service.ApiKey, service.Secret, token);
 			this.token = token;
 		}
+
+		this.flickr.CurrentService = service.Id;
 	}
 
 	public string Token {
 		get { return token; }
 		set {
 			token = value;
-			flickr.ApiToken = value;
+			flickr.AuthToken = value;
 		}
 	}
 
@@ -111,7 +108,7 @@ public class FlickrRemote {
 			try {
 				auth = flickr.AuthGetToken(frob);
 				token = auth.Token;
-				flickr.ApiToken = token;
+				flickr.AuthToken = token;
 
 				return auth;
 			} catch (FlickrNet.FlickrException ex) {
@@ -125,54 +122,50 @@ public class FlickrRemote {
 		return auth;
 	}
 	
-	public string Upload (IBrowsableItem photo, bool scale, int size, bool copy_metadata, bool is_public, bool is_family, bool is_friend)
+	public string Upload (IBrowsableItem photo, IFilter filter, bool is_public, bool is_family, bool is_friend)
 	{
 		if (token == null) {            
 			throw new Exception ("Must Login First");
 		}
 		// FIXME flickr needs rotation
+		string  error_verbose;
 		
-		string path = photo.DefaultVersionUri.LocalPath; 
-		FileInfo file = new FileInfo (path);
-		string   error_verbose;
-		
-		try {            
-			string tags = null;
+		using (FilterRequest request = new FilterRequest (photo.DefaultVersionUri)) {
 			
-			if (scale) {
-				path = PixbufUtils.Resize (path, size, copy_metadata);
-				file = new FileInfo (path);
-			}
-			
-			if (ExportTags && photo.Tags != null) {
-				StringBuilder taglist = new StringBuilder ();
-				Tag [] t = photo.Tags;
+			try {            
+				string tags = null;
 				
-				for (int i = 0; i < t.Length; i++) {
-					if (i > 0)
-						taglist.Append (",");
+
+				filter.Convert (request);
+				string path = request.Current.LocalPath;
+				
+				if (ExportTags && photo.Tags != null) {
+					StringBuilder taglist = new StringBuilder ();
+					Tag [] t = photo.Tags;
 					
-					taglist.Append (String.Format ("\"{0}\"", t[i].Name));
+					for (int i = 0; i < t.Length; i++) {
+						if (i > 0)
+							taglist.Append (",");
+						
+						taglist.Append (String.Format ("\"{0}\"", t[i].Name));
+					}
+					
+					tags = taglist.ToString ();
 				}
-				
-				tags = taglist.ToString ();
+				try {
+					string photoid = 
+						flickr.UploadPicture (path, photo.Name, photo.Description, tags, is_public, is_family, is_friend);
+					return photoid;
+				} catch (FlickrNet.FlickrException ex) {
+					Console.WriteLine ("Problems uploading picture: " + ex.ToString());
+					error_verbose = ex.ToString();
+				}
+			} catch (Exception e) {
+				// FIXME we need to distinguish between file IO errors and xml errors here
+				throw new System.Exception ("Error while uploading", e);
 			}
-			try {
-				string photoid = 
-					flickr.UploadPicture (path, photo.Name, photo.Description, tags, is_public, is_family, is_friend);
-				return photoid;
-			} catch (FlickrNet.FlickrException ex) {
-				Console.WriteLine ("Problems uploading picture: " + ex.ToString());
-				error_verbose = ex.ToString();
-			}
-		} catch (Exception e) {
-			// FIXME we need to distinguish between file IO errors and xml errors here
-			throw new System.Exception ("Error while uploading", e);
-		} finally {
-			if (file != null && scale)
-				file.Delete ();
 		}
-		
+			
 		throw new System.Exception (error_verbose);
 	}
 	
@@ -182,4 +175,37 @@ public class FlickrRemote {
 
 		GnomeUtil.UrlShow (null, login_url);
 	}
+
+	public class Service {
+		public string ApiKey;
+		public string Secret;
+		public SupportedService Id;
+		public string Name;
+		public string PreferencePath;
+		
+		public static Service [] Supported = {
+			new Service (SupportedService.Flickr, "Flickr.com", "c6b39ee183385d9ce4ea188f85945016", "0a951ac44a423a04", Preferences.EXPORT_TOKEN_FLICKR),
+			new Service (SupportedService.TwentyThreeHQ, "23hq.com", "c6b39ee183385d9ce4ea188f85945016", "0a951ac44a423a04", Preferences.EXPORT_TOKEN_23HQ),
+			new Service (SupportedService.Zooomr, "Zooomr.com", "unknown", "unknown", Preferences.EXPORT_TOKEN_ZOOOMR)
+		};
+		
+		public Service (SupportedService id, string name, string api_key, string secret, string pref)
+		{
+			Id = id;
+			ApiKey = api_key;
+			Secret = secret;
+			Name = name;
+			PreferencePath = pref;
+		}
+			
+		public static Service FromSupported (SupportedService id)
+		{
+			foreach (Service s in Supported) {
+				if (s.Id == id)
+					return s;
+			}
+			
+			throw new System.ArgumentException ("Unknown service type");
+		}
+	}
 }
