@@ -542,23 +542,23 @@ namespace FSpot {
 
 		private void Upload ()
 		{
-			try {
-				album.UploadProgress += HandleUploadProgress;
-				sent_bytes = 0;
-				approx_size = 0;
+			album.UploadProgress += HandleUploadProgress;
+			sent_bytes = 0;
+			approx_size = 0;
 
-				System.Console.WriteLine ("Starting Upload to Picasa");
+			System.Console.WriteLine ("Starting Upload to Picasa");
 
-				FilterSet filters = new FilterSet ();
-				filters.Add (new JpegFilter ());
+			FilterSet filters = new FilterSet ();
+			filters.Add (new JpegFilter ());
 
-				if (scale)
-					filters.Add (new ResizeFilter ((uint)size));
+			if (scale)
+				filters.Add (new ResizeFilter ((uint)size));
 
-				if (rotate)
-					filters.Add (new OrientationFilter ());
+			if (rotate)
+				filters.Add (new OrientationFilter ());
 
-				while (photo_index < items.Length) {
+			while (photo_index < items.Length) {
+				try {
 					IBrowsableItem item = items[photo_index];
 
 					FileInfo file_info;
@@ -579,28 +579,47 @@ namespace FSpot {
 					else
 						approx_size = sent_bytes * items.Length / (photo_index - 1);
 
-					album.UploadPicture (request.Current.LocalPath, item.Description);
+					string id = album.UploadPicture (request.Current.LocalPath, item.Description);
+					if (Core.Database != null) {
+						System.UriBuilder uri = new System.UriBuilder (album.Link);
+						uri.Path = uri.Path + "/photo";
+						//Setting the Fragment doesn't display it :( workaround follows
+						string photouri;
+						if (uri.Query == null || uri.Query == String.Empty) {
+							uri.Fragment = id;
+							photouri = uri.ToString () + uri.Fragment;
+						} else {
+							uri.Query = uri.Query.Substring (1) + "#" + id;
+							photouri = uri.ToString ();
+						}
+						Core.Database.Exports.Create ((item as Photo).Id,
+									      (item as Photo).DefaultVersionId,
+									      ExportStore.PicasaExportType,
+									      photouri);
+					}
 
 					sent_bytes += file_info.Length;
 
 					request.Dispose ();
-				}
-				
-				progress_dialog.Message = Catalog.GetString ("Done Sending Photos");
-				progress_dialog.Fraction = 1.0;
-				progress_dialog.ProgressText = Catalog.GetString ("Upload Complete");
-				progress_dialog.ButtonLabel = Gtk.Stock.Ok;
+				} catch (System.Exception e) {
+					progress_dialog.Message = String.Format (Catalog.GetString ("Error Uploading To Gallery: {0}"),
+										 e.Message);
+					progress_dialog.ProgressText = Catalog.GetString ("Error");
+					System.Console.WriteLine (e);
 
-				if (browser) {
-					GnomeUtil.UrlShow (null, album.Link);
+					if (progress_dialog.PerformRetrySkip ())
+					 	photo_index--;
 				}
-			} catch (System.Exception e) {
-				progress_dialog.Message = String.Format (Catalog.GetString ("Error Uploading To Gallery: {0}"),
-									 e.Message);
-				progress_dialog.ProgressText = Catalog.GetString ("Error");
-				System.Console.WriteLine (e);
 			}
-			
+				
+			progress_dialog.Message = Catalog.GetString ("Done Sending Photos");
+			progress_dialog.Fraction = 1.0;
+			progress_dialog.ProgressText = Catalog.GetString ("Upload Complete");
+			progress_dialog.ButtonLabel = Gtk.Stock.Ok;
+
+			if (browser) {
+				GnomeUtil.UrlShow (null, album.Link);
+			}
 		}
 
 		private void HandleScaleCheckToggled (object o, EventArgs e)
